==> cf-variable-resolver-0.0.13.tgz: package/lib/resolvers/secret-store/resolvers/kubernetes-runtime-secret.js <==
const _ = require('lodash');
const errors = require('../../../errors');
const {
    buildSuggestion, buildClient, getCurrentNamespace, getReferences
} = require('../../../clients/kubernetes');
const { buildError, to } = require('../../../utils');

/**
 * resolve a variable from a k8s secret using an in-cluster config
 * @param {*} ctx - secret-context
 * @param {getContextFn} getContext - a function used by the variable resolver to retrieve contexts
 * @param {string} variable - the reference
 * @param {Logger} log - logger
 * @returns {Promise<string>} resolvedVariable
 */
async function resolve(ctx, getContext, variable, log) {
    const { key, name } = getReferences(ctx, variable);
    const [error, namespace] = await to(getCurrentNamespace());
    if (error) {
        throw buildError(errors.Type.FSError, error, 'Make sure namespace file exists on local FS');
    }

    const client = await buildClient({ getContext, log });
    const [err, secret] = await to(async () => client.api.v1.namespace(namespace).secret(name).get());
    if (err) {
        throw buildError(errors.Type.APIRequestError, err);
    }
    const data = _.get(secret, `body.data`, {});
    if (!data || _.isEmpty(data)) {
        const type = _.get(ctx, 'spec.data.resourceType');
        const cluster = _.get(ctx, 'spec.data.cluster');
        throw buildError(errors.Type.IntegrationKeyNotFoundError, undefined, buildSuggestion({
            namespace, key, name, type, cluster
        }));
    }

    return Buffer.from(data[key], 'base64').toString();
}

module.exports = { resolve };

==> cf-variable-resolver-0.0.16.tgz: package/lib/resolvers/secret-store/resolvers/kubernetes-runtime-secret.js <==
const _ = require('lodash');
const errors = require('../../../errors');
const {
    buildSuggestion, buildClient, getCurrentNamespace, getReferences
} = require('../../../clients/kubernetes');
const { buildError, to } = require('../../../utils');

/**
 * resolve a variable from a k8s secret using an in-cluster config
 * @param {*} ctx - secret-context
 * @param {getContextFn} getContext - a function used by the variable resolver to retrieve contexts
 * @param {string} variable - the reference
 * @param {Logger} log - logger
 * @returns {Promise<string>} resolvedVariable
 */
async function resolve(ctx, getContext, variable, log) {
    const { key, name } = getReferences(ctx, variable);
    const [error, namespace] = await to(getCurrentNamespace());
    if (error) {
        throw buildError(errors.Type.FSError, error, 'Make sure namespace file exists on local FS');
    }

    const client = await buildClient({ getContext, log });
    const [err, secret] = await to(async () => client.api.v1.namespace(namespace).secret(name).get());
    if (err) {
        throw buildError(errors.Type.APIRequestError, err);
    }
    const data = _.get(secret, `body.data`, {});
    if (!data || _.isEmpty(data) || !_.has(data, key)) {
        const type = _.get(ctx, 'spec.data.resourceType');
        const cluster = _.get(ctx, 'spec.data.cluster');
        throw buildError(errors.Type.IntegrationKeyNotFoundError, undefined, buildSuggestion({
            namespace, key, name, type, cluster
        }));
    }

    return Buffer.from(data[key], 'base64').toString();
}

module.exports = { resolve };
